@@ -19,8 +19,11 @@ from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
+from neutron_lib.api.definitions import bfd_for_extraroutes
+from neutron_lib.api.definitions import bfd_monitor
 from neutron_lib.api.definitions import bgp
 from neutron_lib.api.definitions import bgp_4byte_asn
+from neutron_lib.api.definitions import bgp_associations
 from neutron_lib.api.definitions import bgp_dragentscheduler
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
@@ -64,8 +67,10 @@ from neutron_lib.api.definitions import l3_ext_gw_mode
 from neutron_lib.api.definitions import l3_ext_ha_mode
 from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
+from neutron_lib.api.definitions import l3_multi_ext_gw
 from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
+from neutron_lib.api.definitions import local_ip
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
@@ -83,6 +88,7 @@ from neutron_lib.api.definitions import port_device_profile
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
+from neutron_lib.api.definitions import port_resource_request_groups
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
@@ -95,9 +101,11 @@ from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
+from neutron_lib.api.definitions import qos_pps_minimum_rule
 from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import quota_check_limit
 from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
 from neutron_lib.api.definitions import rbac_bgpvpn
@@ -147,8 +155,11 @@ _ALL_API_DEFINITIONS = {
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
+    bfd_for_extraroutes,
+    bfd_monitor,
     bgp,
     bgp_4byte_asn,
+    bgp_associations,
     bgp_dragentscheduler,
     bgpvpn,
     bgpvpn_routes_control,
@@ -192,8 +203,10 @@ _ALL_API_DEFINITIONS = {
     l3_ext_ha_mode,
     l3_ext_ndp_proxy,
     l3_flavors,
+    l3_multi_ext_gw,
     l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
+    local_ip,
     logging,
     logging_resource,
     metering,
@@ -211,6 +224,7 @@ _ALL_API_DEFINITIONS = {
     port_mac_address_regenerate,
     port_numa_affinity_policy,
     port_resource_request,
+    port_resource_request_groups,
     port_security,
     portbindings,
     portbindings_extended,
@@ -223,9 +237,11 @@ _ALL_API_DEFINITIONS = {
     qos_default,
     qos_gateway_ip,
     qos_port_network_policy,
+    qos_pps_minimum_rule,
     qos_pps_rule,
     qos_rule_type_details,
     qos_rules_alias,
+    quota_check_limit,
     rbac_address_groups,
     rbac_address_scope,
     rbac_bgpvpn,
