@@ -15,6 +15,8 @@ from neutron_lib import constants
 
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
+    'auth_key',
+    'auth_type',
     'allocation_pools',
     'cidr',
     'default_prefixlen',
@@ -23,8 +25,10 @@ KNOWN_ATTRIBUTES = (
     'device_id',
     'device_owner',
     'dns_nameservers',
+    'dst_ip',
     'enable_dhcp',
     'enable_ndp_proxy',
+    'external_gateways',
     'fixed_ips',
     'gateway_ip',
     'host_routes',
@@ -36,6 +40,10 @@ KNOWN_ATTRIBUTES = (
     'mac_address',
     'max_prefixlen',
     'min_prefixlen',
+    'min_rx',
+    'min_tx',
+    'mode',
+    'multiplier',
     'name',
     'network_id',
     'port_id',
@@ -45,10 +53,12 @@ KNOWN_ATTRIBUTES = (
     'qos_policy_id',
     'service_types',
     constants.SHARED,
+    'src_ip',
     'status',
     'subnets',
     'subnetpool_id',
-    'tenant_id'
+    'tenant_id',
+    'type'
 )
 
 KNOWN_RESOURCES = (
@@ -84,6 +94,7 @@ KNOWN_EXTENSIONS = (
     'allowed-address-pairs',
     'auto-allocated-topology',
     'availability_zone',
+    'bfd-monitor',
     'binding',
     'data-plane-status',
     'project-default-networks',
@@ -118,6 +129,7 @@ KNOWN_EXTENSIONS = (
     'metering',
     'metering_source_and_destination_filters',
     'multi-provider',
+    'multiple-external-gateways',
     'net-mtu',
     'network-ip-availability',
     'network-segment-range',
@@ -133,6 +145,7 @@ KNOWN_EXTENSIONS = (
     'qos-port-network-policy',
     'qos-rules-alias',
     'quotas',
+    'quota-check-limit',
     'rbac-address-group',
     'rbac-address-scope',
     'rbac-bgpvpn',
